@@ -26,14 +26,13 @@
 #else
   #include <libavcore/imgutils.h>
 #endif
-#ifdef HAVE_SOUND
-// TODO: use libavresample instead if available
-  #if HAVE_SOUND==avresample
-    #include <libavutil/opt.h>
-    #include <libavresample/avresample.h>
-  #else
-    #include <libswresample/swresample.h>
-  #endif
+// Use libavresample instead if available
+#ifdef HAVE_AVRESAMPLE
+  #include <libavutil/opt.h>
+  #include <libavresample/avresample.h>
+  #include <ao/ao.h>
+#elif defined(HAVE_SWRESAMPLE)
+  #include <libswresample/swresample.h>
   #include <ao/ao.h>
 #endif
 #include <gtk/gtk.h>
@@ -78,20 +77,19 @@ struct viddata
   AVCodec* vdecoder;
   AVCodec* vencoder;
   AVCodec* adecoder;
-#ifdef HAVE_SOUND
+#ifdef HAVE_AVRESAMPLE
   int audiopipe;
-  #if HAVE_SOUND==avresample
-    AVAudioResampleContext* resamplectx;
-  #else
-    SwrContext* swrctx;
-  #endif
+  AVAudioResampleContext* resamplectx;
+#elif defined(HAVE_SWRESAMPLE)
+  int audiopipe;
+  SwrContext* swrctx;
 #endif
 };
 
 int tc_client[2];
 int tc_client_in[2];
 
-#ifdef HAVE_SOUND
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
 // Experimental mixer, not sure if it really works
 void camera_playsnd(struct viddata* data, struct camera* cam, short* samples, unsigned int samplecount)
 {
@@ -132,7 +130,7 @@ void camera_remove(struct viddata* data, const char* nick)
       gtk_widget_destroy(data->cams[i].box);
       av_frame_free(&data->cams[i].frame);
       avcodec_free_context(&data->cams[i].vctx);
-#ifdef HAVE_SOUND
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
       avcodec_free_context(&data->cams[i].actx);
 #endif
       free(data->cams[i].id);
@@ -203,7 +201,7 @@ gboolean handledata(GIOChannel* channel, GIOCondition condition, gpointer datap)
     cam->id=strdup(id);
     cam->vctx=avcodec_alloc_context3(data->vdecoder);
     avcodec_open2(cam->vctx, data->vdecoder, 0);
-#ifdef HAVE_SOUND
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
     cam->actx=avcodec_alloc_context3(data->adecoder);
     avcodec_open2(cam->actx, data->adecoder, 0);
     cam->samples=0;
@@ -260,7 +258,7 @@ gboolean handledata(GIOChannel* channel, GIOCondition condition, gpointer datap)
     {
       pos+=read(tc_client[0], pkt.data+pos, size-pos);
     }
-#ifdef HAVE_SOUND
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
     // Find the camera representation for the given ID (for decoder context)
     struct camera* cam=0;
     for(i=0; i<data->camcount; ++i)
@@ -271,10 +269,10 @@ gboolean handledata(GIOChannel* channel, GIOCondition condition, gpointer datap)
     int gotframe;
     avcodec_decode_audio4(cam->actx, cam->frame, &gotframe, &pkt);
     if(!gotframe){return 1;}
-  #if HAVE_SOUND==avresample
+  #ifdef HAVE_AVRESAMPLE
     int outlen=avresample_convert(data->resamplectx, cam->frame->data, cam->frame->linesize[0], cam->frame->nb_samples, cam->frame->data, cam->frame->linesize[0], cam->frame->nb_samples);
   #else
-    int outlen=swr_convert(data->resamplectx, cam->frame->data, cam->frame->nb_samples, (const uint8_t**)cam->frame->data, cam->frame->nb_samples);
+    int outlen=swr_convert(data->swrctx, cam->frame->data, cam->frame->nb_samples, (const uint8_t**)cam->frame->data, cam->frame->nb_samples);
   #endif
     camera_playsnd(data, cam, (short*)cam->frame->data[0], outlen);
 #endif
@@ -332,7 +330,7 @@ gboolean handledata(GIOChannel* channel, GIOCondition condition, gpointer datap)
   return 1;
 }
 
-#ifdef HAVE_SOUND
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
 void audiothread(int fd)
 {
   ao_initialize();
@@ -457,8 +455,8 @@ int main(int argc, char** argv)
   data.vdecoder=avcodec_find_decoder(AV_CODEC_ID_FLV1);
   data.adecoder=avcodec_find_decoder(AV_CODEC_ID_NELLYMOSER);
 
-#ifdef HAVE_SOUND
-  #if HAVE_SOUND==avresample
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
+  #ifdef HAVE_AVRESAMPLE
   data.resamplectx=avresample_alloc_context();
   av_opt_set_int(data.resamplectx, "in_channel_layout", AV_CH_FRONT_CENTER, 0);
   av_opt_set_int(data.resamplectx, "in_sample_fmt", AV_SAMPLE_FMT_FLT, 0);
@@ -469,7 +467,7 @@ int main(int argc, char** argv)
   av_opt_set_int(data.resamplectx, "out_sample_rate", 22050, 0);
   avresample_open(data.resamplectx);
   #else
-  data.resamplectx=swr_alloc_set_opts(0, AV_CH_FRONT_CENTER, AV_SAMPLE_FMT_S16, 22050, AV_CH_FRONT_CENTER, AV_SAMPLE_FMT_FLT, 11025, 0, 0);
+  data.swrctx=swr_alloc_set_opts(0, AV_CH_FRONT_CENTER, AV_SAMPLE_FMT_S16, 22050, AV_CH_FRONT_CENTER, AV_SAMPLE_FMT_FLT, 11025, 0, 0);
   swr_init(data.swrctx);
   #endif
   int audiopipe[2];
@@ -524,13 +522,12 @@ int main(int argc, char** argv)
   {
     av_frame_free(&data.cams[i].frame);
     avcodec_free_context(&data.cams[i].vctx);
-#ifdef HAVE_SOUND
+#ifdef HAVE_AVRESAMPLE
     avcodec_free_context(&data.cams[i].actx);
-  #if HAVE_SOUND==avresample
     avresample_free(&data.resamplectx);
-  #else
+#elif defined(HAVE_SWRESAMPLE)
+    avcodec_free_context(&data.cams[i].actx);
     swr_free(&data.swrctx);
-  #endif
 #endif
     free(data.cams[i].id);
     free(data.cams[i].nick);
