@@ -1,6 +1,7 @@
 /*
     tc_client-gtk, a graphical user interface for tc_client
     Copyright (C) 2015  alicia@ion.nu
+    Copyright (C) 2015  Pamela Hiatt
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as published by
@@ -28,14 +29,13 @@
 #else
   #include <libavcore/imgutils.h>
 #endif
-#ifdef HAVE_SOUND
-  // Use libavresample if available, otherwise fall back on libswresample
-  #if HAVE_SOUND==avresample
-    #include <libavutil/opt.h>
-    #include <libavresample/avresample.h>
-  #else
-    #include <libswresample/swresample.h>
-  #endif
+// Use libavresample if available, otherwise fall back on libswresample
+#ifdef HAVE_AVRESAMPLE
+  #include <libavutil/opt.h>
+  #include <libavresample/avresample.h>
+  #include <ao/ao.h>
+#elif defined(HAVE_SWRESAMPLE)
+  #include <libswresample/swresample.h>
   #include <ao/ao.h>
 #endif
 #include <gtk/gtk.h>
@@ -60,13 +60,12 @@ struct viddata
   AVCodec* adecoder;
   int scalewidth;
   int scaleheight;
-#ifdef HAVE_SOUND
+#ifdef HAVE_AVRESAMPLE
   int audiopipe;
-  #if HAVE_SOUND==avresample
-    AVAudioResampleContext* resamplectx;
-  #else
-    SwrContext* swrctx;
-  #endif
+  AVAudioResampleContext* resamplectx;
+#elif defined(HAVE_SWRESAMPLE)
+  int audiopipe;
+  SwrContext* swrctx;
 #endif
   GtkTextBuffer* buffer; // TODO: struct buffer array, for PMs
   GtkAdjustment* scroll;
@@ -77,6 +76,7 @@ int tc_client[2];
 int tc_client_in[2];
 const char* channel=0;
 const char* mycolor=0;
+char* nickname=0;
 
 void updatescaling(struct viddata* data, unsigned int width, unsigned int height)
 {
@@ -166,6 +166,13 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
     }
     return 1;
   }
+  if(!strncmp(buf, "Connection ID: ", 15)) // Our initial nickname is "guest-" plus our connection ID
+  {
+    unsigned int length=strlen(&buf[15]);
+    nickname=malloc(length+strlen("guest-")+1);
+    sprintf(nickname, "guest-%s", &(buf[15]));
+    return 1;
+  }
   // Start streams once we're properly connected
   if(!strncmp(buf, "Currently on cam: ", 18))
   {
@@ -274,6 +281,12 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
           cam->nick=strdup(&space[21]);
           gtk_label_set_text(GTK_LABEL(cam->label), cam->nick);
         }
+        // If it was us, keep track of the new nickname
+        if(!strcmp(nickname, nick))
+        {
+          free(nickname);
+          nickname=strdup(&space[21]);
+        }
       }
     }
     free(color);
@@ -334,7 +347,7 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
     cam->id=strdup(id);
     cam->vctx=avcodec_alloc_context3(data->vdecoder);
     avcodec_open2(cam->vctx, data->vdecoder, 0);
-#ifdef HAVE_SOUND
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
     cam->actx=avcodec_alloc_context3(data->adecoder);
     avcodec_open2(cam->actx, data->adecoder, 0);
     cam->samples=0;
@@ -357,7 +370,7 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
     struct camera* cam=camera_new();
     cam->frame=av_frame_alloc();
     cam->dstframe=av_frame_alloc();
-    cam->nick=strdup("You");
+    cam->nick=strdup(nickname);
     cam->id=strdup("out");
     cam->vctx=avcodec_alloc_context3(data->vdecoder);
     avcodec_open2(cam->vctx, data->vdecoder, 0);
@@ -400,17 +413,17 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
     {
       pos+=read(fd, pkt.data+pos, size-pos);
     }
-#ifdef HAVE_SOUND
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
     // Find the camera representation for the given ID (for decoder context)
     struct camera* cam=camera_find(&buf[7]);
     if(!cam){printf("No cam found with ID '%s'\n", &buf[7]); return 1;}
     int gotframe;
     avcodec_decode_audio4(cam->actx, cam->frame, &gotframe, &pkt);
     if(!gotframe){return 1;}
-  #if HAVE_SOUND==avresample
+  #ifdef HAVE_AVRESAMPLE
     int outlen=avresample_convert(data->resamplectx, cam->frame->data, cam->frame->linesize[0], cam->frame->nb_samples, cam->frame->data, cam->frame->linesize[0], cam->frame->nb_samples);
   #else
-    int outlen=swr_convert(data->resamplectx, cam->frame->data, cam->frame->nb_samples, (const uint8_t**)cam->frame->data, cam->frame->nb_samples);
+    int outlen=swr_convert(data->swrctx, cam->frame->data, cam->frame->nb_samples, (const uint8_t**)cam->frame->data, cam->frame->nb_samples);
   #endif
     camera_playsnd(data->audiopipe, cam, (short*)cam->frame->data[0], outlen);
 #endif
@@ -463,7 +476,7 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
   return 1;
 }
 
-#ifdef HAVE_SOUND
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
 void audiothread(int fd)
 {
   ao_initialize();
@@ -676,11 +689,11 @@ void sendmessage(GtkEntry* entry, struct viddata* data)
     gtk_entry_set_text(entry, "");
     return;
   }
-  char text[strlen("[00:00] ")+strlen("You: ")+strlen(msg)+1];
+  char text[strlen("[00:00] ")+strlen(nickname)+strlen(": ")+strlen(msg)+1];
   time_t timestamp=time(0);
   struct tm* t=localtime(&timestamp);
   sprintf(text, "[%02i:%02i] ", t->tm_hour, t->tm_min);
-  sprintf(&text[8], "You: %s", msg);
+  sprintf(&text[8], "%s: %s", nickname, msg);
   if(config_get_bool("enable_logging")){logger_write(text, channel, 0);}
   printchat_color(data, text, mycolor, 8);
   gtk_entry_set_text(entry, "");
@@ -758,8 +771,8 @@ int main(int argc, char** argv)
   data.vdecoder=avcodec_find_decoder(AV_CODEC_ID_FLV1);
   data.adecoder=avcodec_find_decoder(AV_CODEC_ID_NELLYMOSER);
 
-#ifdef HAVE_SOUND
-  #if HAVE_SOUND==avresample
+#if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
+  #ifdef HAVE_AVRESAMPLE
   data.resamplectx=avresample_alloc_context();
   av_opt_set_int(data.resamplectx, "in_channel_layout", AV_CH_FRONT_CENTER, 0);
   av_opt_set_int(data.resamplectx, "in_sample_fmt", AV_SAMPLE_FMT_FLT, 0);
@@ -770,7 +783,7 @@ int main(int argc, char** argv)
   av_opt_set_int(data.resamplectx, "out_sample_rate", 22050, 0);
   avresample_open(data.resamplectx);
   #else
-  data.resamplectx=swr_alloc_set_opts(0, AV_CH_FRONT_CENTER, AV_SAMPLE_FMT_S16, 22050, AV_CH_FRONT_CENTER, AV_SAMPLE_FMT_FLT, 11025, 0, 0);
+  data.swrctx=swr_alloc_set_opts(0, AV_CH_FRONT_CENTER, AV_SAMPLE_FMT_S16, 22050, AV_CH_FRONT_CENTER, AV_SAMPLE_FMT_FLT, 11025, 0, 0);
   swr_init(data.swrctx);
   #endif
   int audiopipe[2];
@@ -877,12 +890,10 @@ int main(int argc, char** argv)
   gtk_main();
  
   camera_cleanup();
-#ifdef HAVE_SOUND
-  #if HAVE_SOUND==avresample
+#ifdef HAVE_AVRESAMPLE
   avresample_free(&data.resamplectx);
-  #else
+#elif defined(HAVE_SWRESAMPLE)
   swr_free(&data.swrctx);
-  #endif
 #endif
   return 0;
 }
